﻿# -*- coding: utf8 -*-

import requests
import pandas as pd
from flask import Flask, make_response, jsonify, request, render_template

__author__ = 'YingJoy'

app = Flask(__name__)
GD_KEY = '高德地图开发Key'


@app.route('/')
def index():
    """助手首页"""
    return render_template('index.html')


@app.route('/weather', methods=['POST'])
def weather_assistant():
    """
    天气查询助手，用于【玩转腾讯云】打造你的私人 AI 助手
    AKID0mIWUN9asajeLrBdwynnW2La3GEvxOmv
    d1HJOIwOcbM6aw2rSnxuzqfFPK9pI0eO
    """
    request_body = request.json

    # 获取参数，这里为了演示就不做其他校验，直接取数据
    city_name = request_body['SlotInfoList'][0]['SlotValue']
    request_id = request_body['RequestId']

    # 读取城市编号，这是采用了高德地图的接口，详见：https://lbs.amap.com/api/webservice/guide/api/weatherinfo
    df = pd.read_excel('static/AMap_adcode_citycode_2020_4_10.xlsx', encoding='utf8')
    adcode = df[df['中文名'] == city_name]['adcode']
    if adcode.empty:
        # 如果城市不存在，返回错误，TBP会自动进行追问，当然也可以返回TBP支持的Response Body, 在WebHookStatus中指定错误
        return make_response('城市错误', 400)

    resp = requests.get(f'https://restapi.amap.com/v3/weather/weatherInfo?key={GD_KEY}&city={int(adcode)}')
    # 如果高德地图接口调用失败报错
    if resp.json()['status'] != '1':
        return make_response(str(resp.json()), 500)

    # 格式化天气格式
    weather_result = resp.json()['lives'][0]
    query_date = weather_result['reporttime']
    province = weather_result['province']
    weather = weather_result['weather']
    temperature = weather_result['temperature']
    humidity = weather_result['humidity']
    winddirection = weather_result['winddirection']
    windpower = weather_result['windpower']
    response_message = f"截至{query_date}，{province} - {city_name}的天气为{weather}，" \
                       f"温度：{temperature}°，湿度：{humidity}，风向：{winddirection}，风力：{windpower}。"

    # 构造返回体
    return jsonify({
        "RequestId": request_id,
        "SessionAttributes": "string",
        "ResponseMessage": {
            "ContentType": "PlainText",
            "Content": response_message
        },
        "WebHookStatus": ""
    })


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=4006, debug=True)
